Logo fantomas

DaemonOperations<'daemon> Type

How the cache reaches the world. Only the two things it cannot answer for itself: everything a daemon knows about itself is on `IDaemon`.

Record fields

Record Field Description

Create

Full Usage: Create

Field type: FantomasVersion -> FantomasToolStartInfo -> Result<'daemon, ProcessStartError>

FindTool

Full Usage: FindTool

Field type: Folder -> Result<FantomasToolFound, FantomasToolError>

Type something to start searching.