Logo fantomas

ChainLink Type

A single link in a method-call or property-access chain (e.g. a.b().c[0]). The chain is represented as an ordered list of ChainLink values so that the printer can decide whether to keep the chain on one line or break at each dot.

Union cases

Union case Description

AppUnit LinkSingleAppUnit

Full Usage: AppUnit LinkSingleAppUnit

Parameters:

Dot SingleTextNode

Full Usage: Dot SingleTextNode

Parameters:

Expr Expr

Full Usage: Expr Expr

Parameters:
Item : Expr

Identifier Expr

Full Usage: Identifier Expr

Parameters:
Item : Expr

IndexExpr Expr

Full Usage: IndexExpr Expr

Parameters:
Item : Expr

Instance members

Instance member Description

this.IsAppParen

Full Usage: this.IsAppParen

Returns: bool
Returns: bool

this.IsAppUnit

Full Usage: this.IsAppUnit

Returns: bool
Returns: bool

this.IsDot

Full Usage: this.IsDot

Returns: bool
Returns: bool

this.IsExpr

Full Usage: this.IsExpr

Returns: bool
Returns: bool

this.IsIdentifier

Full Usage: this.IsIdentifier

Returns: bool
Returns: bool

this.IsIndexExpr

Full Usage: this.IsIndexExpr

Returns: bool
Returns: bool

Static members

Static member Description

ChainLink.Node(link)

Full Usage: ChainLink.Node(link)

Parameters:
Returns: Node
link : ChainLink
Returns: Node

Type something to start searching.