ElseIfNode Type
An `else if` pair — the `else` and `if` keywords are stored as separate ranges so trivia can be attached correctly.
Constructors
| Constructor |
Description
|
|
|
An `else if` pair — the `else` and `if` keywords are stored as separate ranges so trivia can be attached correctly.
| Constructor |
Description
|
|
|