ExprConstantNode Type
A constant (literal) expression leaf node such as `42`, `"hello"`, `true`, or `3.14`. This node has no child nodes; all textual content is carried by the source range.
Constructors
| Constructor |
Description
|
|
|
A constant (literal) expression leaf node such as `42`, `"hello"`, `true`, or `3.14`. This node has no child nodes; all textual content is carried by the source range.
| Constructor |
Description
|
|
|