Logo fantomas

ExprSpreadNode Type

Example: `...source` — a spread of an existing value into a record or anonymous record expression. The source is an arbitrary expression, the same grammar as the right-hand side of a field.

Constructors

Constructor Description

ExprSpreadNode(dots, expr, range)

Full Usage: ExprSpreadNode(dots, expr, range)

Parameters:
Returns: ExprSpreadNode
dots : SingleTextNode
expr : Expr
range : range
Returns: ExprSpreadNode

Instance members

Instance member Description

this.Dots

Full Usage: this.Dots

Returns: SingleTextNode
Returns: SingleTextNode

this.Expr

Full Usage: this.Expr

Returns: Expr
Returns: Expr

Inherited members

Inherited from NodeBase

Instance members

Instance member Description

this.AddAfter

Full Usage: this.AddAfter

Parameters:
triviaNode : TriviaNode

this.AddBefore

Full Usage: this.AddBefore

Parameters:
triviaNode : TriviaNode

this.AddCursor

Full Usage: this.AddCursor

Parameters:
cursor : pos

this.AppendToStringWithIndent

Full Usage: this.AppendToStringWithIndent

Parameters:
sb : StringBuilder
depth : int

this.ToStringWithIndent

Full Usage: this.ToStringWithIndent

Parameters:
    depth : int

Returns: string
depth : int
Returns: string

this.HasContentAfter

Full Usage: this.HasContentAfter

Returns: bool
Returns: bool

this.Range

Full Usage: this.Range

Returns: range
Returns: range

this.HasAnyContentAfter

Full Usage: this.HasAnyContentAfter

Returns: bool
Returns: bool

this.ContentAfter

Full Usage: this.ContentAfter

Returns: TriviaNode seq
Returns: TriviaNode seq

this.Children

Full Usage: this.Children

Returns: Node array
Modifiers: abstract
Returns: Node array

this.HasContentBefore

Full Usage: this.HasContentBefore

Returns: bool
Returns: bool

this.TryGetCursor

Full Usage: this.TryGetCursor

Returns: pos option
Returns: pos option

this.ContentBefore

Full Usage: this.ContentBefore

Returns: TriviaNode seq
Returns: TriviaNode seq

this.HasAnyContentBefore

Full Usage: this.HasAnyContentBefore

Returns: bool
Returns: bool

Type something to start searching.