Logo fantomas

InheritConstructor Type

Discriminated union for the argument form following an inherit declaration. Covers the four constructor syntax variants: bare type, unit (), parenthesised argument list, and any other expression argument form.

Union cases

Union case Description

Instance members

Instance member Description

this.InheritKeyword

Full Usage: this.InheritKeyword

Returns: SingleTextNode
Returns: SingleTextNode

Static members

Static member Description

InheritConstructor.Node(ic)

Full Usage: InheritConstructor.Node(ic)

Parameters:
Returns: Node
ic : InheritConstructor
Returns: Node

Type something to start searching.