MultipleTextsNode Type
A node holding two or more adjacent text tokens that logically form one keyword or modifier sequence. Example: `static member` (two tokens), `abstract default` (access + keyword).
Constructors
| Constructor |
Description
|
Full Usage:
MultipleTextsNode(content, range)
Parameters:
SingleTextNode list
range : range
Returns: MultipleTextsNode
|
|
Instance members
| Instance member |
Description
|
|
|
Inherited members
Inherited from
NodeBase
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
Full Usage:
this.ToStringWithIndent
Parameters:
int
Returns: string
|
|
|
|
|
|
Full Usage:
this.HasContentAfter
Returns: bool
|
|
Full Usage:
this.HasContentBefore
Returns: bool
|
|
|
|
|
|
|
|
fantomas