Logo fantomas

RationalConstNode Type

Discriminated union for the three forms of a rational-number exponent in a unit-of-measure type annotation (e.g. m/s^2). An exponent can be a plain integer, a rational fraction 3/2, or a negated form of either.

Union cases

Union case Description

Integer SingleTextNode

Full Usage: Integer SingleTextNode

Parameters:

Rational RationalNode

Full Usage: Rational RationalNode

Parameters:

Instance members

Instance member Description

this.IsInteger

Full Usage: this.IsInteger

Returns: bool
Returns: bool

this.IsNegate

Full Usage: this.IsNegate

Returns: bool
Returns: bool

this.IsRational

Full Usage: this.IsRational

Returns: bool
Returns: bool

Static members

Static member Description

RationalConstNode.Node(r)

Full Usage: RationalConstNode.Node(r)

Parameters:
Returns: Node
r : RationalConstNode
Returns: Node

Type something to start searching.