Logo fantomas

TyparDecls Type

Discriminated union for the three syntactic forms of type-parameter declaration. PostfixList is the {'T, 'U} style; PrefixList is ('T, 'U); SinglePrefix is a bare 'T in contexts where only one parameter is present.

Union cases

Union case Description

SinglePrefix TyparDeclNode

Full Usage: SinglePrefix TyparDeclNode

Parameters:

Instance members

Instance member Description

this.IsPostfixList

Full Usage: this.IsPostfixList

Returns: bool
Returns: bool

this.IsPrefixList

Full Usage: this.IsPrefixList

Returns: bool
Returns: bool

this.IsSinglePrefix

Full Usage: this.IsSinglePrefix

Returns: bool
Returns: bool

Static members

Static member Description

TyparDecls.Node(td)

Full Usage: TyparDecls.Node(td)

Parameters:
Returns: Node
td : TyparDecls
Returns: Node

Type something to start searching.