TypeAppPostFixNode Type
Example: `int list` or `string option` — a postfix type application where the type argument precedes the type name.
Constructors
| Constructor |
Description
|
|
|
Example: `int list` or `string option` — a postfix type application where the type argument precedes the type name.
| Constructor |
Description
|
|
|