ILAttribElem Type
Union cases
| Union case |
Description
|
|
|
Full Usage:
Bool bool
Parameters:
bool
|
|
Full Usage:
Byte byte
Parameters:
byte
|
|
Full Usage:
Char char
Parameters:
char
|
|
Full Usage:
Double double
Parameters:
double
|
|
|
Represents an enum value together with its enum type. Used when an enum is stored in a custom-attribute argument of type 'object', so the enum type is preserved in the encoded blob (ECMA-335 II.23.3) instead of being collapsed to its underlying integer. The second element is the underlying integer value (e.g. ILAttribElem.Int32).
|
Full Usage:
Int16 int16
Parameters:
int16
|
|
Full Usage:
Int32 int32
Parameters:
int32
|
|
Full Usage:
Int64 int64
Parameters:
int64
|
|
Full Usage:
Null
|
|
Full Usage:
SByte sbyte
Parameters:
sbyte
|
|
Full Usage:
Single single
Parameters:
single
|
|
Full Usage:
String string option
Parameters:
string option
|
Represents a custom attribute parameter of type 'string'. These may be null, in which case they are encoded in a special way as indicated by Ecma-335 Partition II.
|
|
|
|
|
Full Usage:
UInt16 uint16
Parameters:
uint16
|
|
Full Usage:
UInt32 uint32
Parameters:
uint32
|
|
Full Usage:
UInt64 uint64
Parameters:
uint64
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsArray
Returns: bool
|
|
Full Usage:
this.IsBool
Returns: bool
|
|
Full Usage:
this.IsByte
Returns: bool
|
|
Full Usage:
this.IsChar
Returns: bool
|
|
Full Usage:
this.IsDouble
Returns: bool
|
|
Full Usage:
this.IsEnum
Returns: bool
|
|
Full Usage:
this.IsInt16
Returns: bool
|
|
Full Usage:
this.IsInt32
Returns: bool
|
|
Full Usage:
this.IsInt64
Returns: bool
|
|
Full Usage:
this.IsNull
Returns: bool
|
|
Full Usage:
this.IsSByte
Returns: bool
|
|
Full Usage:
this.IsSingle
Returns: bool
|
|
Full Usage:
this.IsString
Returns: bool
|
|
Full Usage:
this.IsType
Returns: bool
|
|
Full Usage:
this.IsTypeRef
Returns: bool
|
|
Full Usage:
this.IsUInt16
Returns: bool
|
|
Full Usage:
this.IsUInt32
Returns: bool
|
|
Full Usage:
this.IsUInt64
Returns: bool
|
|
fantomas