Logo fantomas

ILMethodDefs Type

Tables of methods. Logically equivalent to a list of methods but the table is kept in a form optimized for looking up methods by name and arity.

Instance members

Instance member Description

this.AsArray

Full Usage: this.AsArray

Returns: ILMethodDef[]
Returns: ILMethodDef[]

this.AsList

Full Usage: this.AsList

Returns: ILMethodDef list
Returns: ILMethodDef list

this.FindByName

Full Usage: this.FindByName

Parameters:
    arg0 : string

Returns: ILMethodDef list
arg0 : string
Returns: ILMethodDef list

this.TryFindInstanceByNameAndCallingSignature

Full Usage: this.TryFindInstanceByNameAndCallingSignature

Parameters:
Returns: ILMethodDef option
arg0 : string
arg1 : ILCallingSignature
Returns: ILMethodDef option

Inherited members

Inherited from DelayInitArrayMap<ILMethodDef, string, ILMethodDef list>

Instance members

Instance member Description

this.CreateDictionary

Full Usage: this.CreateDictionary

Parameters:
    arg0 : 'T[]

Returns: IDictionary<'TDictKey, 'TDictValue>
Modifiers: abstract
arg0 : 'T[]
Returns: IDictionary<'TDictKey, 'TDictValue>

this.GetArray

Full Usage: this.GetArray

Returns: 'T[]
Returns: 'T[]

this.GetDictionary

Full Usage: this.GetDictionary

Returns: IDictionary<'TDictKey, 'TDictValue>
Returns: IDictionary<'TDictKey, 'TDictValue>

Type something to start searching.