Logo fantomas

CacheMetrics Module

Functions and values

Function or value Description

CaptureStatsAndWriteToConsole ()

Full Usage: CaptureStatsAndWriteToConsole ()

Parameters:
    () : unit

Returns: IDisposable
() : unit
Returns: IDisposable

ListenToAll ()

Full Usage: ListenToAll ()

Parameters:
    () : unit

Returns: IDisposable
() : unit
Returns: IDisposable

Meter

Full Usage: Meter

Returns: Meter

Global telemetry Meter for all caches. Exposed for testing purposes. Set FSHARP_OTEL_EXPORT environment variable to enable OpenTelemetry export to external collectors in tests.

Returns: Meter

StatsToString ()

Full Usage: StatsToString ()

Parameters:
    () : unit

Returns: string
() : unit
Returns: string

getRatioByName name

Full Usage: getRatioByName name

Parameters:
    name : string

Returns: float

Current hit ratio (hits / (hits + misses)) aggregated across all cache instances with the given name.

name : string
Returns: float

getTotalsByName name

Full Usage: getTotalsByName name

Parameters:
    name : string

Returns: Map<string, int64>

Current metric totals aggregated across all cache instances with the given name. Totals only accumulate while a listener from ListenToAll is running.

name : string
Returns: Map<string, int64>

Type something to start searching.