LanguageVersion Type
LanguageVersion management
Constructors
| Constructor |
Description
|
Full Usage:
LanguageVersion(arg1, ?disabledFeaturesArray)
Parameters:
string
?disabledFeaturesArray : LanguageFeature array
Returns: LanguageVersion
|
Create a LanguageVersion management object
|
Instance members
| Instance member |
Description
|
|
Get the disabled features
|
Full Usage:
this.IsExplicitlySpecifiedAs50OrBefore
Returns: bool
|
Has been explicitly specified as 4.6, 4.7 or 5.0
|
Full Usage:
this.IsPreviewEnabled
Returns: bool
|
Has preview been explicitly specified
|
Full Usage:
this.SpecifiedVersion
Returns: decimal
|
Get the specified LanguageVersion
|
Full Usage:
this.SpecifiedVersionString
Returns: string
|
Get the specified LanguageVersion as a string
|
|
Does the selected LanguageVersion support the specified feature
|
Full Usage:
this.VersionText
Returns: string
|
Get the text used to specify the version, several of which may map to the same version
|
Full Usage:
this.WithDisabledFeatures
Parameters:
LanguageFeature array
Returns: LanguageVersion
|
Create a new LanguageVersion with updated disabled features
|
Static members
| Static member |
Description
|
Full Usage:
LanguageVersion.ContainsVersion(arg1)
Parameters:
string
Returns: bool
|
Is the selected LanguageVersion valid
|
|
|
Full Usage:
LanguageVersion.GetFeatureString(feature)
Parameters:
LanguageFeature
Returns: string
|
|
Full Usage:
LanguageVersion.GetFeatureVersionString(feature)
Parameters:
LanguageFeature
Returns: string
|
|
Full Usage:
LanguageVersion.IsVersionSupported(arg1)
Parameters:
string
Returns: bool
|
Is the selected LanguageVersion currently supported
|
Full Usage:
LanguageVersion.TryParseFeature(featureName)
Parameters:
string
Returns: LanguageFeature option
|
Try to parse a feature name string to a LanguageFeature option
|
Full Usage:
LanguageVersion.ValidOptions
Returns: string[]
|
Get the list of valid options
|
Full Usage:
LanguageVersion.ValidVersions
Returns: string[]
|
Get the list of valid versions
|
fantomas