Logo fantomas

FileSystemUtils Module

Filesystem helpers

Functions and values

Function or value Description

FileSystemUtils.checkPathForIllegalChars

Full Usage: FileSystemUtils.checkPathForIllegalChars

Returns: string -> unit
Returns: string -> unit

FileSystemUtils.checkSuffix path suffix

Full Usage: FileSystemUtils.checkSuffix path suffix

Parameters:
    path : string
    suffix : string

Returns: bool

checkSuffix f s returns True if file name "f" ends in suffix "s", e.g. checkSuffix "abc.fs" ".fs" returns true. Disregards casing, e.g. checkSuffix "abc.Fs" ".fs" returns true.

path : string
suffix : string
Returns: bool

FileSystemUtils.chopExtension path

Full Usage: FileSystemUtils.chopExtension path

Parameters:
    path : string

Returns: string

chopExtension f removes the extension from the given file name. Raises ArgumentException if no extension is present.

path : string
Returns: string

FileSystemUtils.fileNameOfPath path

Full Usage: FileSystemUtils.fileNameOfPath path

Parameters:
    path : string

Returns: string

Get the file name of the given path.

path : string
Returns: string

FileSystemUtils.fileNameWithoutExtension path

Full Usage: FileSystemUtils.fileNameWithoutExtension path

Parameters:
    path : string

Returns: string
path : string
Returns: string

FileSystemUtils.fileNameWithoutExtensionWithValidate validate path

Full Usage: FileSystemUtils.fileNameWithoutExtensionWithValidate validate path

Parameters:
    validate : bool
    path : string

Returns: string

Get the file name without extension of the given path.

validate : bool
path : string
Returns: string

FileSystemUtils.hasExtension path

Full Usage: FileSystemUtils.hasExtension path

Parameters:
    path : string

Returns: bool

Return True if the path has a "." extension.

path : string
Returns: bool

FileSystemUtils.isDll fileName

Full Usage: FileSystemUtils.isDll fileName

Parameters:
    fileName : string

Returns: bool

Checks whether file is dll (ends in .dll)

fileName : string
Returns: bool

FileSystemUtils.trimQuotes path

Full Usage: FileSystemUtils.trimQuotes path

Parameters:
    path : string

Returns: string

Trim the quotes and spaces from either end of a string

path : string
Returns: string

Type something to start searching.