LexFilter Type
A stateful filter over the token stream that adjusts it for indentation-aware syntax rules Process the token stream prior to parsing. Implements the offside rule and other lexical transformations.
Constructors
| Constructor |
Description
|
|
fantomas