Range Module
Functions and values
| Function or value |
Description
|
|
Equality comparer for range.
|
|
|
|
|
|
|
|
|
|
Output a range
|
The zero range
|
|
|
|
|
A range associated with a dummy file for the command line arguments
|
|
|
|
|
|
|
|
|
|
A range associated with a dummy file called "startup"
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
fantomas