Lexbuf Type
Instance members
| Instance member |
Description
|
|
Dynamically typed, non-lexically scoped parameter table.
|
|
The end position for the lexeme.
|
Full Usage:
this.IsPastEndOfStream
Returns: bool
|
True if the refill of the buffer ever failed , or if explicitly set to True.
|
|
Get the language version being supported
|
|
The currently matched text as a Span, it is only valid until the lexer is advanced
|
Full Usage:
this.ReportLibraryOnlyFeatures
Returns: bool
|
Determines if the parser can report FSharpCore library-only features.
|
|
The start position for the lexeme.
|
Full Usage:
this.StrictIndentation
Returns: bool option
|
|
fantomas