Extras Module
Types and nested modules
| Type/Module | Description |
|
Specialized parallel functions for an array. Different from Array.Parallel as it will try to minimize the max degree of parallelism. Will flatten aggregate exceptions that contain one exception. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Track a set of resources to cleanup |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
In some cases we play games where we use 'null' as a more efficient representation in F#. The functions below are used to give initial values to mutable fields. This is an unsafe trick, as it relies on the fact that the type of values being placed into the slot never utilizes "null" as a representation. To be used with with care. |
|
|
Caches, mainly for free variables |
Functions and values
| Function or value |
Description
|
Full Usage:
GetEnvInteger e dflt
Parameters:
string
dflt : int
Returns: int
|
|
|
|
Full Usage:
cacheOptByref cache f
Parameters:
byref<'T option>
f : unit -> 'T
Returns: 'T
Modifiers: inline Type parameters: 'T |
|
Full Usage:
cacheOptRef cache f
Parameters:
'a option ref
f : unit -> 'a
Returns: 'a
Modifiers: inline Type parameters: 'a |
|
Full Usage:
cached cache resF
Parameters:
cache<'a>
resF : unit -> 'a
Returns: 'a
Modifiers: inline Type parameters: 'a (requires not struct) |
|
Full Usage:
debug
Returns: bool
|
|
|
|
Full Usage:
fold1Of2 f1 acc (a1, _a2)
Parameters:
'a -> 'b -> 'c
acc : 'a
a1 : 'b
_a2 : 'd
Returns: 'c
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
foldPair (f1, f2) acc (a1, a2)
Parameters:
'a -> 'b -> 'c
f2 : 'c -> 'd -> 'e
acc : 'a
a1 : 'b
a2 : 'd
Returns: 'e
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
foldQuadruple (f1, f2, f3, f4) acc (a1, a2, a3, a4)
Parameters:
'a -> 'b -> 'c
f2 : 'c -> 'd -> 'e
f3 : 'e -> 'f -> 'g
f4 : 'g -> 'h -> 'i
acc : 'a
a1 : 'b
a2 : 'd
a3 : 'f
a4 : 'h
Returns: 'i
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i |
|
Full Usage:
foldTriple (f1, f2, f3) acc (a1, a2, a3)
Parameters:
'a -> 'b -> 'c
f2 : 'c -> 'd -> 'e
f3 : 'e -> 'f -> 'g
acc : 'a
a1 : 'b
a2 : 'd
a3 : 'f
Returns: 'g
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f, 'g |
|
Full Usage:
isEnvVarSet s
Parameters:
string
Returns: bool
|
|
Full Usage:
map1Of2 f (a1, a2)
Parameters:
'a -> 'b
a1 : 'a
a2 : 'c
Returns: 'b * 'c
Type parameters: 'a, 'b, 'c |
|
Full Usage:
map1Of3 f (a1, a2, a3)
Parameters:
'a -> 'b
a1 : 'a
a2 : 'c
a3 : 'd
Returns: 'b * 'c * 'd
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
map2Of2 f (a1, a2)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'a
Returns: 'c * 'b
Type parameters: 'a, 'b, 'c |
|
Full Usage:
map2Of3 f (a1, a2, a3)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'a
a3 : 'd
Returns: 'c * 'b * 'd
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
map3Of3 f (a1, a2, a3)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'd
a3 : 'a
Returns: 'c * 'd * 'b
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
map3Of4 f (a1, a2, a3, a4)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'd
a3 : 'a
a4 : 'e
Returns: 'c * 'd * 'b * 'e
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
map4Of4 f (a1, a2, a3, a4)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'd
a3 : 'e
a4 : 'a
Returns: 'c * 'd * 'e * 'b
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
map5Of5 f (a1, a2, a3, a4, a5)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'd
a3 : 'e
a4 : 'f
a5 : 'a
Returns: 'c * 'd * 'e * 'f * 'b
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f |
|
Full Usage:
map6Of6 f (a1, a2, a3, a4, a5, a6)
Parameters:
'a -> 'b
a1 : 'c
a2 : 'd
a3 : 'e
a4 : 'f
a5 : 'g
a6 : 'a
Returns: 'c * 'd * 'e * 'f * 'g * 'b
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f, 'g |
|
Full Usage:
mapFoldFst f s (x, y)
Parameters:
'a -> 'b -> 'c * 'd
s : 'a
x : 'b
y : 'e
Returns: ('c * 'e) * 'd
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
mapFoldSnd f s (x, y)
Parameters:
'a -> 'b -> 'c * 'd
s : 'a
x : 'e
y : 'b
Returns: ('e * 'c) * 'd
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
mapPair (f1, f2) (a1, a2)
Parameters:
'a -> 'b
f2 : 'c -> 'd
a1 : 'a
a2 : 'c
Returns: 'b * 'd
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
mapQuadruple (f1, f2, f3, f4) (a1, a2, a3, a4)
Parameters:
'a -> 'b
f2 : 'c -> 'd
f3 : 'e -> 'f
f4 : 'g -> 'h
a1 : 'a
a2 : 'c
a3 : 'e
a4 : 'g
Returns: 'b * 'd * 'f * 'h
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h |
|
Full Usage:
mapTriple (f1, f2, f3) (a1, a2, a3)
Parameters:
'a -> 'b
f2 : 'c -> 'd
f3 : 'e -> 'f
a1 : 'a
a2 : 'c
a3 : 'e
Returns: 'b * 'd * 'f
Type parameters: 'a, 'b, 'c, 'd, 'e, 'f |
|
Full Usage:
newCache ()
Parameters:
unit
Returns: cache<'a>
Type parameters: 'a (requires not struct) |
|
Full Usage:
nullableSlotEmpty ()
Parameters:
unit
Returns: NonNullSlot<'T>
Type parameters: 'T (requires not struct) |
|
Full Usage:
nullableSlotFull x
Parameters:
'a
Returns: NonNullSlot<'a>
Type parameters: 'a (requires not struct) |
|
Full Usage:
p13 (x, _y, _z)
Parameters:
'a
_y : 'b
_z : 'c
Returns: 'a
Type parameters: 'a, 'b, 'c |
|
Full Usage:
p14 (x1, _x2, _x3, _x4)
Parameters:
'a
_x2 : 'b
_x3 : 'c
_x4 : 'd
Returns: 'a
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
p15 (x1, _x2, _x3, _x4, _x5)
Parameters:
'a
_x2 : 'b
_x3 : 'c
_x4 : 'd
_x5 : 'e
Returns: 'a
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
p23 (_x, y, _z)
Parameters:
'a
y : 'b
_z : 'c
Returns: 'b
Type parameters: 'a, 'b, 'c |
|
Full Usage:
p24 (_x1, x2, _x3, _x4)
Parameters:
'a
x2 : 'b
_x3 : 'c
_x4 : 'd
Returns: 'b
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
p25 (_x1, x2, _x3, _x4, _x5)
Parameters:
'a
x2 : 'b
_x3 : 'c
_x4 : 'd
_x5 : 'e
Returns: 'b
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
p33 (_x, _y, z)
Parameters:
'a
_y : 'b
z : 'c
Returns: 'c
Type parameters: 'a, 'b, 'c |
|
Full Usage:
p34 (_x1, _x2, x3, _x4)
Parameters:
'a
_x2 : 'b
x3 : 'c
_x4 : 'd
Returns: 'c
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
p35 (_x1, _x2, x3, _x4, _x5)
Parameters:
'a
_x2 : 'b
x3 : 'c
_x4 : 'd
_x5 : 'e
Returns: 'c
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
p44 (_x1, _x2, _x3, x4)
Parameters:
'a
_x2 : 'b
_x3 : 'c
x4 : 'd
Returns: 'd
Type parameters: 'a, 'b, 'c, 'd |
|
Full Usage:
p45 (_x1, _x2, _x3, x4, _x5)
Parameters:
'a
_x2 : 'b
_x3 : 'c
x4 : 'd
_x5 : 'e
Returns: 'd
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
p55 (_x1, _x2, _x3, _x4, x5)
Parameters:
'a
_x2 : 'b
_x3 : 'c
_x4 : 'd
x5 : 'e
Returns: 'e
Type parameters: 'a, 'b, 'c, 'd, 'e |
|
Full Usage:
pair a b
Parameters:
'a
b : 'b
Returns: 'a * 'b
Type parameters: 'a, 'b |
|
Full Usage:
progress
Returns: bool
|
|
Full Usage:
tracking
Returns: bool
|
|
Full Usage:
tryGetCacheValue cache
Parameters:
cache<'a>
Returns: NonNullSlot<'a> voption
Modifiers: inline Type parameters: 'a (requires not struct) |
|
Full Usage:
verbose
Returns: bool
|
|
Full Usage:
vsnd arg1
Parameters:
'T * 'T
Returns: 'T
Modifiers: inline Type parameters: 'T |
|
|
Writing to output stream via a string buffer.
|
Type extensions
| Type extension |
Description
|
Full Usage:
this.AppendString
Parameters:
string
|
fantomas