ResizeArray Module
Generic operations on the type System.Collections.Generic.List, which is called ResizeArray in the F# libraries.
Functions and values
| Function or value |
Description
|
Full Usage:
append arg1 arg2
Parameters:
ResizeArray<'T>
arg1 : ResizeArray<'T>
Returns: ResizeArray<'T>
Type parameters: 'T |
Build a new array that contains the elements of the first array followed by the elements of the second array.
|
Full Usage:
blit arg1 arg2 arg3 arg4 arg5
Parameters:
ResizeArray<'T>
arg1 : int
arg2 : ResizeArray<'T>
arg3 : int
arg4 : int
Type parameters: 'T |
Read a range of elements from the first array and write them into the second.
|
Full Usage:
choose arg1 arg2
Parameters:
'T -> 'U option
arg1 : ResizeArray<'T>
Returns: ResizeArray<'U>
Type parameters: 'T, 'U |
Apply the given function to each element of the array. Return
the array comprised of the results "x" for each element where
the function returns
|
Full Usage:
concat arg1
Parameters:
ResizeArray<'T> list
Returns: ResizeArray<'T>
Type parameters: 'T |
Build a new array that contains the elements of each of the given list of arrays.
|
Full Usage:
copy arg1
Parameters:
ResizeArray<'T>
Returns: ResizeArray<'T>
Type parameters: 'T |
Build a new array that contains the elements of the given array.
|
Full Usage:
create arg1 arg2
Parameters:
int
arg1 : 'T
Returns: ResizeArray<'T>
Type parameters: 'T |
Create an array whose elements are all initially the given value.
|
Full Usage:
exists arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: bool
Type parameters: 'T |
Test if any element of the array satisfies the given predicate.
If the input function is
|
Full Usage:
exists2 arg1 arg2 arg3
Parameters:
'T -> 'U -> bool
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Returns: bool
Type parameters: 'T, 'U |
Test elements of the two arrays pairwise to see if any pair of element satisfies the given predicate. Raise ArgumentException if the arrays have different lengths.
|
Full Usage:
fill arg1 arg2 arg3 arg4
Parameters:
ResizeArray<'T>
arg1 : int
arg2 : int
arg3 : 'T
Type parameters: 'T |
Fill a range of the collection with the given element.
|
Full Usage:
filter arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: ResizeArray<'T>
Type parameters: 'T |
Return a new collection containing only the elements of the collection for which the given predicate returns True.
|
Full Usage:
find arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: 'T
Type parameters: 'T |
Return the first element for which the given function returns True.
Raise
|
Full Usage:
findIndex arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: int
Type parameters: 'T |
Return the index of the first element in the array
that satisfies the given predicate. Raise
|
Full Usage:
findIndexi arg1 arg2
Parameters:
int -> 'T -> bool
arg1 : ResizeArray<'T>
Returns: int
Type parameters: 'T |
Return the index of the first element in the array
that satisfies the given predicate. Raise
|
Full Usage:
fold arg1 arg2 arg3
Parameters:
'T -> 'U -> 'T
arg1 : 'T
arg2 : ResizeArray<'U>
Returns: 'T
Type parameters: 'T, 'U |
Apply a function to each element of the collection, threading an accumulator argument
through the computation. If the input function is
|
Full Usage:
fold2 arg1 arg2 arg3 arg4
Parameters:
'state -> 'b1 -> 'b2 -> 'state
arg1 : 'state
arg2 : ResizeArray<'b1>
arg3 : ResizeArray<'b2>
Returns: 'state
Type parameters: 'state, 'b1, 'b2 |
Apply a function to pairs of elements drawn from the two collections,
left-to-right, threading an accumulator argument
through the computation. The two input
arrays must have the same lengths, otherwise an
|
Full Usage:
foldBack arg1 arg2 arg3
Parameters:
'T -> 'U -> 'U
arg1 : ResizeArray<'T>
arg2 : 'U
Returns: 'U
Type parameters: 'T, 'U |
Apply a function to each element of the array, threading an accumulator argument
through the computation. If the input function is
|
Full Usage:
foldBack2 arg1 arg2 arg3 arg4
Parameters:
'a1 -> 'a2 -> 'U -> 'U
arg1 : ResizeArray<'a1>
arg2 : ResizeArray<'a2>
arg3 : 'U
Returns: 'U
Type parameters: 'a1, 'a2, 'U |
Apply a function to pairs of elements drawn from the two collections, right-to-left,
threading an accumulator argument through the computation. The two input
arrays must have the same lengths, otherwise an
|
Full Usage:
forall arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: bool
Type parameters: 'T |
Test if all elements of the array satisfy the given predicate.
If the input function is
|
Full Usage:
forall2 arg1 arg2 arg3
Parameters:
'T -> 'U -> bool
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Returns: bool
Type parameters: 'T, 'U |
Test elements of the two arrays pairwise to see if all pairs of elements satisfy the given predicate.
Raise
|
Full Usage:
get arg1 arg2
Parameters:
ResizeArray<'T>
arg1 : int
Returns: 'T
Type parameters: 'T |
Fetch an element from the collection. You can also use the syntax
|
Full Usage:
init arg1 arg2
Parameters:
int
arg1 : int -> 'T
Returns: ResizeArray<'T>
Type parameters: 'T |
Create an array by calling the given generator on each index.
|
Full Usage:
isEmpty arg1
Parameters:
ResizeArray<'T>
Returns: bool
Type parameters: 'T |
Return True if the given array is empty, otherwise False.
|
Full Usage:
iter arg1 arg2
Parameters:
'T -> unit
arg1 : ResizeArray<'T>
Type parameters: 'T |
Apply the given function to each element of the array.
|
Full Usage:
iter2 arg1 arg2 arg3
Parameters:
'T -> 'U -> unit
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Type parameters: 'T, 'U |
Apply the given function to two arrays simultaneously. The two arrays must have the same lengths, otherwise an Invalid_argument exception is raised.
|
Full Usage:
iteri arg1 arg2
Parameters:
int -> 'T -> unit
arg1 : ResizeArray<'T>
Type parameters: 'T |
Apply the given function to each element of the array. The integer passed to the function indicates the index of element.
|
Full Usage:
iteri2 arg1 arg2 arg3
Parameters:
int -> 'T -> 'U -> unit
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Type parameters: 'T, 'U |
Apply the given function to pair of elements drawn from matching indices in two arrays,
also passing the index of the elements. The two arrays must have the same lengths,
otherwise an
|
Full Usage:
length arg1
Parameters:
ResizeArray<'T>
Returns: int
Type parameters: 'T |
Return the length of the collection. You can also use property
|
Full Usage:
map arg1 arg2
Parameters:
'T -> 'U
arg1 : ResizeArray<'T>
Returns: ResizeArray<'U>
Type parameters: 'T, 'U |
Build a new array whose elements are the results of applying the given function to each of the elements of the array.
|
Full Usage:
map2 arg1 arg2 arg3
Parameters:
'T -> 'U -> 'c
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Returns: ResizeArray<'c>
Type parameters: 'T, 'U, 'c |
Build a new collection whose elements are the results of applying the given function to the corresponding elements of the two collections pairwise. The two input arrays must have the same lengths.
|
Full Usage:
mapi arg1 arg2
Parameters:
int -> 'T -> 'U
arg1 : ResizeArray<'T>
Returns: ResizeArray<'U>
Type parameters: 'T, 'U |
Build a new array whose elements are the results of applying the given function to each of the elements of the array. The integer index passed to the function indicates the index of element being transformed.
|
Full Usage:
mapi2 arg1 arg2 arg3
Parameters:
int -> 'T -> 'U -> 'c
arg1 : ResizeArray<'T>
arg2 : ResizeArray<'U>
Returns: ResizeArray<'c>
Type parameters: 'T, 'U, 'c |
Build a new collection whose elements are the results of applying the given function
to the corresponding elements of the two collections pairwise. The two input
arrays must have the same lengths, otherwise an
|
Full Usage:
ofArray arg1
Parameters:
'T[]
Returns: ResizeArray<'T>
Type parameters: 'T |
Build a
|
Full Usage:
ofList arg1
Parameters:
'T list
Returns: ResizeArray<'T>
Type parameters: 'T |
Build an array from the given list.
|
Full Usage:
partition arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: ResizeArray<'T> * ResizeArray<'T>
Type parameters: 'T |
Split the collection into two collections, containing the elements for which the given predicate returns True and False respectively.
|
Full Usage:
reduce arg1 arg2
Parameters:
'T -> 'T -> 'T
arg1 : ResizeArray<'T>
Returns: 'T
Type parameters: 'T |
Apply a function to each element of the array, threading an accumulator argument
through the computation. If the input function is
|
Full Usage:
reduceBack arg1 arg2
Parameters:
'T -> 'T -> 'T
arg1 : ResizeArray<'T>
Returns: 'T
Type parameters: 'T |
Apply a function to each element of the array, threading an accumulator argument
through the computation. If the input function is
|
Full Usage:
rev arg1
Parameters:
ResizeArray<'T>
Returns: ResizeArray<'T>
Type parameters: 'T |
Return a new array with the elements in reverse order.
|
Full Usage:
scan arg1 arg2 arg3
Parameters:
'U -> 'T -> 'U
arg1 : 'U
arg2 : ResizeArray<'T>
Returns: ResizeArray<'U>
Type parameters: 'U, 'T |
Like
|
Full Usage:
scanBack arg1 arg2 arg3
Parameters:
'T -> 'c -> 'c
arg1 : ResizeArray<'T>
arg2 : 'c
Returns: ResizeArray<'c>
Type parameters: 'T, 'c |
Like
|
Full Usage:
set arg1 arg2 arg3
Parameters:
ResizeArray<'T>
arg1 : int
arg2 : 'T
Type parameters: 'T |
Set the value of an element in the collection. You can also use the syntax
|
Full Usage:
singleton arg1
Parameters:
'T
Returns: ResizeArray<'T>
Type parameters: 'T |
Return an array containing the given element.
|
Full Usage:
sort arg1 arg2
Parameters:
'T -> 'T -> int
arg1 : ResizeArray<'T>
Type parameters: 'T |
Sort the elements using the given comparison function.
|
Full Usage:
sortBy arg1 arg2
Parameters:
'T -> 'Key
arg1 : ResizeArray<'T>
Type parameters: 'T, 'Key (requires comparison) |
Sort the elements using the key extractor and generic comparison on the keys.
|
Full Usage:
sub arg1 arg2 arg3
Parameters:
ResizeArray<'T>
arg1 : int
arg2 : int
Returns: ResizeArray<'T>
Type parameters: 'T |
Build a new array that contains the given subrange specified by starting index and length.
|
Full Usage:
toArray arg1
Parameters:
ResizeArray<'T>
Returns: 'T[]
Type parameters: 'T |
Return a fixed-length array containing the elements of the input
|
Full Usage:
toList arg1
Parameters:
ResizeArray<'T>
Returns: 'T list
Type parameters: 'T |
Build a list from the given array.
|
Full Usage:
toSeq arg1
Parameters:
ResizeArray<'T>
Returns: 'T seq
Type parameters: 'T |
Return a view of the array as an enumerable object.
|
Full Usage:
tryFind arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: 'T option
Type parameters: 'T |
Return the first element for which the given function returns True. Return None if no such element exists.
|
Full Usage:
tryFindIndex arg1 arg2
Parameters:
'T -> bool
arg1 : ResizeArray<'T>
Returns: int option
Type parameters: 'T |
Return the index of the first element in the array that satisfies the given predicate.
|
Full Usage:
tryFindIndexi arg1 arg2
Parameters:
int -> 'T -> bool
arg1 : ResizeArray<'T>
Returns: int option
Type parameters: 'T |
Return the index of the first element in the array that satisfies the given predicate.
|
Full Usage:
tryPick arg1 arg2
Parameters:
'T -> 'U option
arg1 : ResizeArray<'T>
Returns: 'U option
Type parameters: 'T, 'U |
Apply the given function to successive elements, returning the first result where function returns Some(x) for some x.
|
Full Usage:
unzip arg1
Parameters:
ResizeArray<'T * 'U>
Returns: ResizeArray<'T> * ResizeArray<'U>
Type parameters: 'T, 'U |
Split an array of pairs into two arrays.
|
Full Usage:
zip arg1 arg2
Parameters:
ResizeArray<'T>
arg1 : ResizeArray<'U>
Returns: ResizeArray<'T * 'U>
Type parameters: 'T, 'U |
Combine the two arrays into an array of pairs. The two arrays must have equal lengths, otherwise an
|
fantomas