DaemonOperations<'daemon> Type
How the cache reaches the world. Only the two things it cannot answer for itself: everything a daemon knows about itself is on `IDaemon`.
Record fields
| Record Field |
Description
|
Full Usage:
Create
Field type: FantomasVersion -> FantomasToolStartInfo -> Result<'daemon, ProcessStartError>
|
|
|
|
fantomas