FantomasVersion Type
A Fantomas version in the one shape daemons are cached under: as `dotnet tool list` writes it,
with no `Fantomas` in front, no leading `v`, no `+
A Fantomas version in the one shape daemons are cached under: as `dotnet tool list` writes it,
with no `Fantomas` in front, no leading `v`, no `+