Header menu logo fantomas

Fantomas.Core Namespace

Type/Module Description

AssemblyVersionInformation

ASTTransformer

Async

CodeFormatter

CodeFormatterImpl

CodePrinter

Context

Continuation

DefineCombination

DefineParseException

Raised when one or more conditional compilation define combinations produce invalid syntax trees.

Defines

EndOfLineStyle

FormatConfig

FormatException

Raised when Fantomas encounters a problem during formatting.

FormatResult

List

MultilineBracketStyle

MultilineFormatterType

MultipleDefineCombinations

Num

ParseException

Raised when the F# parser produces errors for source code without conditional directives.

Queue

Queue<'T>

append only collection optimized for quick append of block of data and query operations data - list of blocks in reverse order

RangeHelpers

RangePatterns

Selection

String

SyntaxOak

Trivia

Validation

Version

WriterEvent

Represents a single event emitted during the code formatting process. The sequence of writer events captures how the formatter produces its output.

Type something to start searching.