Fantomas.Core Namespace
| Type/Module | Description |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Raised when one or more conditional compilation define combinations produce invalid syntax trees. |
|
|
|
|
|
|
|
|
|
|
|
Raised when Fantomas encounters a problem during formatting. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Raised when the F# parser produces errors for source code without conditional directives. |
|
|
|
|
|
append only collection optimized for quick append of block of data and query operations data - list of blocks in reverse order |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Represents a single event emitted during the code formatting process. The sequence of writer events captures how the formatter produces its output. |
fantomas