ExprDynamicChainNode Type
Example: `x?a("")?b(t)` — a chain of two or more `?` operator accesses. Captured as a dedicated node so the printer can keep `?member(arg)` tight, because adding a space before the paren argument changes parsing of the following `?member`. See #3159.
Constructors
| Constructor |
Description
|
Full Usage:
ExprDynamicChainNode(leadingExpr, items, range)
Parameters:
Expr
items : ExprDynamicChainItemNode list
range : range
Returns: ExprDynamicChainNode
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
Inherited members
Inherited from
NodeBase
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
Full Usage:
this.ToStringWithIndent
Parameters:
int
Returns: string
|
|
|
|
Full Usage:
this.HasContentAfter
Returns: bool
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.HasContentBefore
Returns: bool
|
|
fantomas