ExprSpreadNode Type
Example: `...source` — a spread of an existing value into a record or anonymous record expression. The source is an arbitrary expression, the same grammar as the right-hand side of a field.
Constructors
| Constructor |
Description
|
Full Usage:
ExprSpreadNode(dots, expr, range)
Parameters:
SingleTextNode
expr : Expr
range : range
Returns: ExprSpreadNode
|
|
Instance members
| Instance member |
Description
|
|
|
|
Inherited members
Inherited from
NodeBase
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
Full Usage:
this.ToStringWithIndent
Parameters:
int
Returns: string
|
|
Full Usage:
this.HasContentAfter
Returns: bool
|
|
|
|
Full Usage:
this.HasAnyContentAfter
Returns: bool
|
|
|
|
|
|
Full Usage:
this.HasContentBefore
Returns: bool
|
|
|
|
|
|
Full Usage:
this.HasAnyContentBefore
Returns: bool
|
|
fantomas