Logo fantomas

InheritConstructor Type

Discriminated union for the argument form following an inherit declaration. Covers the four constructor syntax variants: bare type, unit (), parenthesised argument list, and any other expression argument form.

Union cases

Union case Description

Instance members

Instance member Description

this.InheritKeyword

Full Usage: this.InheritKeyword

Returns: SingleTextNode
Returns: SingleTextNode

this.IsOther

Full Usage: this.IsOther

Returns: bool
Returns: bool

this.IsParen

Full Usage: this.IsParen

Returns: bool
Returns: bool

this.IsTypeOnly

Full Usage: this.IsTypeOnly

Returns: bool
Returns: bool

this.IsUnit

Full Usage: this.IsUnit

Returns: bool
Returns: bool

Static members

Static member Description

InheritConstructor.Node(ic)

Full Usage: InheritConstructor.Node(ic)

Parameters:
Returns: Node
ic : InheritConstructor
Returns: Node

Type something to start searching.