ITypeDefn Type
Interface implemented by all type-definition node types that carry a type name and a
member list. Used to access the common parts of a type definition (its header and
members) without matching on every
Instance members
| Instance member |
Description
|
|
|
|
|
fantomas