Header menu logo fantomas

WriterEvent Type

Represents a single event emitted during the code formatting process. The sequence of writer events captures how the formatter produces its output.

Union cases

Union case Description

IndentBy indent

Full Usage: IndentBy indent

Parameters:
    indent : int

indent : int

NodeEnd(endNodeType, endRange)

Full Usage: NodeEnd(endNodeType, endRange)

Parameters:
    endNodeType : string
    endRange : string

endNodeType : string
endRange : string

NodeStart(nodeType, range)

Full Usage: NodeStart(nodeType, range)

Parameters:
    nodeType : string
    range : string

nodeType : string
range : string

RestoreAtColumn restoreAtColumn

Full Usage: RestoreAtColumn restoreAtColumn

Parameters:
    restoreAtColumn : int

restoreAtColumn : int

RestoreIndent restoreIndent

Full Usage: RestoreIndent restoreIndent

Parameters:
    restoreIndent : int

restoreIndent : int

SetAtColumn setAtColumn

Full Usage: SetAtColumn setAtColumn

Parameters:
    setAtColumn : int

setAtColumn : int

SetIndent setIndent

Full Usage: SetIndent setIndent

Parameters:
    setIndent : int

setIndent : int

UnIndentBy unindent

Full Usage: UnIndentBy unindent

Parameters:
    unindent : int

unindent : int

Write text

Full Usage: Write text

Parameters:
    text : string

text : string

WriteBeforeNewline content

Full Usage: WriteBeforeNewline content

Parameters:
    content : string

content : string

WriteLine

Full Usage: WriteLine

WriteLineBecauseOfTrivia

Full Usage: WriteLineBecauseOfTrivia

WriteLineInsideStringConst

Full Usage: WriteLineInsideStringConst

WriteLineInsideTrivia

Full Usage: WriteLineInsideTrivia

Instance members

Instance member Description

this.IsIndentBy

Full Usage: this.IsIndentBy

Returns: bool
Returns: bool

this.IsNodeEnd

Full Usage: this.IsNodeEnd

Returns: bool
Returns: bool

this.IsNodeStart

Full Usage: this.IsNodeStart

Returns: bool
Returns: bool

this.IsRestoreAtColumn

Full Usage: this.IsRestoreAtColumn

Returns: bool
Returns: bool

this.IsRestoreIndent

Full Usage: this.IsRestoreIndent

Returns: bool
Returns: bool

this.IsSetAtColumn

Full Usage: this.IsSetAtColumn

Returns: bool
Returns: bool

this.IsSetIndent

Full Usage: this.IsSetIndent

Returns: bool
Returns: bool

this.IsUnIndentBy

Full Usage: this.IsUnIndentBy

Returns: bool
Returns: bool

this.IsWrite

Full Usage: this.IsWrite

Returns: bool
Returns: bool

this.IsWriteBeforeNewline

Full Usage: this.IsWriteBeforeNewline

Returns: bool
Returns: bool

this.IsWriteLine

Full Usage: this.IsWriteLine

Returns: bool
Returns: bool

this.IsWriteLineBecauseOfTrivia

Full Usage: this.IsWriteLineBecauseOfTrivia

Returns: bool
Returns: bool

this.IsWriteLineInsideStringConst

Full Usage: this.IsWriteLineInsideStringConst

Returns: bool
Returns: bool

this.IsWriteLineInsideTrivia

Full Usage: this.IsWriteLineInsideTrivia

Returns: bool
Returns: bool

Type something to start searching.