WriterEvent Type
Represents a single event emitted during the code formatting process. The sequence of writer events captures how the formatter produces its output.
Union cases
| Union case |
Description
|
Full Usage:
IndentBy indent
Parameters:
int
|
|
Full Usage:
NodeEnd(endNodeType, endRange)
Parameters:
string
endRange : string
|
|
Full Usage:
NodeStart(nodeType, range)
Parameters:
string
range : string
|
|
Full Usage:
RestoreAtColumn restoreAtColumn
Parameters:
int
|
|
Full Usage:
RestoreIndent restoreIndent
Parameters:
int
|
|
Full Usage:
SetAtColumn setAtColumn
Parameters:
int
|
|
Full Usage:
SetIndent setIndent
Parameters:
int
|
|
Full Usage:
UnIndentBy unindent
Parameters:
int
|
|
Full Usage:
Write text
Parameters:
string
|
|
Full Usage:
WriteBeforeNewline content
Parameters:
string
|
|
Full Usage:
WriteLine
|
|
Full Usage:
WriteLineBecauseOfTrivia
|
|
Full Usage:
WriteLineInsideStringConst
|
|
Full Usage:
WriteLineInsideTrivia
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsIndentBy
Returns: bool
|
|
Full Usage:
this.IsNodeEnd
Returns: bool
|
|
Full Usage:
this.IsNodeStart
Returns: bool
|
|
Full Usage:
this.IsRestoreAtColumn
Returns: bool
|
|
Full Usage:
this.IsRestoreIndent
Returns: bool
|
|
Full Usage:
this.IsSetAtColumn
Returns: bool
|
|
Full Usage:
this.IsSetIndent
Returns: bool
|
|
Full Usage:
this.IsUnIndentBy
Returns: bool
|
|
Full Usage:
this.IsWrite
Returns: bool
|
|
Full Usage:
this.IsWriteBeforeNewline
Returns: bool
|
|
Full Usage:
this.IsWriteLine
Returns: bool
|
|
Full Usage:
this.IsWriteLineBecauseOfTrivia
Returns: bool
|
|
Full Usage:
this.IsWriteLineInsideStringConst
Returns: bool
|
|
Full Usage:
this.IsWriteLineInsideTrivia
Returns: bool
|
|
fantomas