ILMethodDefs Type
Tables of methods. Logically equivalent to a list of methods but the table is kept in a form optimized for looking up methods by name and arity.
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
Full Usage:
this.TryFindInstanceByNameAndCallingSignature
Parameters:
string
arg1 : ILCallingSignature
Returns: ILMethodDef option
|
|
Inherited members
Inherited from
DelayInitArrayMap<ILMethodDef, string, ILMethodDef list>
Instance members
| Instance member |
Description
|
Full Usage:
this.CreateDictionary
Parameters:
'T[]
Returns: IDictionary<'TDictKey, 'TDictValue>
Modifiers: abstract |
|
Full Usage:
this.GetArray
Returns: 'T[]
|
|
|
|
fantomas