Logo fantomas

ILTypeDefs Type

Tables of named type definitions.

Instance members

Instance member Description

this.AsArray

Full Usage: this.AsArray

Returns: ILTypeDef[]
Returns: ILTypeDef[]

this.AsArrayOfPreTypeDefs

Full Usage: this.AsArrayOfPreTypeDefs

Returns: ILPreTypeDef[]

Get some information about the type defs, but do not force the read of the type defs themselves.

Returns: ILPreTypeDef[]

this.AsList

Full Usage: this.AsList

Returns: ILTypeDef list
Returns: ILTypeDef list

this.ExistsByName

Full Usage: this.ExistsByName

Parameters:
    arg0 : string

Returns: bool

Calls to ExistsByName will result in all the ILPreTypeDefs being read.

arg0 : string
Returns: bool

this.FindByName

Full Usage: this.FindByName

Parameters:
    arg0 : string

Returns: ILTypeDef

Calls to FindByName will result in all the ILPreTypeDefs being read.

arg0 : string
Returns: ILTypeDef

Inherited members

Inherited from DelayInitArrayMap<ILPreTypeDef, (string list * string), ILPreTypeDef>

Instance members

Instance member Description

this.CreateDictionary

Full Usage: this.CreateDictionary

Parameters:
    arg0 : 'T[]

Returns: IDictionary<'TDictKey, 'TDictValue>
Modifiers: abstract
arg0 : 'T[]
Returns: IDictionary<'TDictKey, 'TDictValue>

this.GetArray

Full Usage: this.GetArray

Returns: 'T[]
Returns: 'T[]

this.GetDictionary

Full Usage: this.GetDictionary

Returns: IDictionary<'TDictKey, 'TDictValue>
Returns: IDictionary<'TDictKey, 'TDictValue>

Type something to start searching.