ILTypeDefs Type
Tables of named type definitions.
Instance members
| Instance member |
Description
|
|
|
|
Get some information about the type defs, but do not force the read of the type defs themselves.
|
|
|
Full Usage:
this.ExistsByName
Parameters:
string
Returns: bool
|
Calls to
|
|
Calls to
|
Inherited members
Inherited from
DelayInitArrayMap<ILPreTypeDef, (string list * string), ILPreTypeDef>
Instance members
| Instance member |
Description
|
Full Usage:
this.CreateDictionary
Parameters:
'T[]
Returns: IDictionary<'TDictKey, 'TDictValue>
Modifiers: abstract |
|
Full Usage:
this.GetArray
Returns: 'T[]
|
|
|
|
fantomas