CacheMetrics Module
Functions and values
| Function or value |
Description
|
|
|
|
|
Global telemetry Meter for all caches. Exposed for testing purposes. Set FSHARP_OTEL_EXPORT environment variable to enable OpenTelemetry export to external collectors in tests.
|
|
Full Usage:
StatsToString ()
Parameters:
unit
Returns: string
|
|
Full Usage:
getRatioByName name
Parameters:
string
Returns: float
|
Current hit ratio (hits / (hits + misses)) aggregated across all cache instances with the given name.
|
|
Current metric totals aggregated across all cache instances with the given name. Totals only accumulate while a listener from ListenToAll is running.
|
fantomas