FileSystemUtils Module
Filesystem helpers
Functions and values
| Function or value |
Description
|
Full Usage:
FileSystemUtils.checkPathForIllegalChars
Returns: string -> unit
|
|
Full Usage:
FileSystemUtils.checkSuffix path suffix
Parameters:
string
suffix : string
Returns: bool
|
|
Full Usage:
FileSystemUtils.chopExtension path
Parameters:
string
Returns: string
|
|
Full Usage:
FileSystemUtils.fileNameOfPath path
Parameters:
string
Returns: string
|
Get the file name of the given path.
|
Full Usage:
FileSystemUtils.fileNameWithoutExtension path
Parameters:
string
Returns: string
|
|
Full Usage:
FileSystemUtils.fileNameWithoutExtensionWithValidate validate path
Parameters:
bool
path : string
Returns: string
|
Get the file name without extension of the given path.
|
Full Usage:
FileSystemUtils.hasExtension path
Parameters:
string
Returns: bool
|
Return True if the path has a "." extension.
|
Full Usage:
FileSystemUtils.isDll fileName
Parameters:
string
Returns: bool
|
Checks whether file is dll (ends in .dll)
|
Full Usage:
FileSystemUtils.trimQuotes path
Parameters:
string
Returns: string
|
Trim the quotes and spaces from either end of a string
|
fantomas