Suggestion Module
Functions and values
| Function or value |
Description
|
|
|
The candidate closest to `term`, when one is within `limit` edits of it, and `None` when the nearest is far enough away that naming it would be a guess rather than help. Two candidates the same distance away are separated by the order of `candidates`, since `List.sortBy` is stable. |
fantomas